########################################
TDK Lambda Genesys 40-38 DC power supply
########################################

.. autoclass:: pymeasure.instruments.tdk.tdk_gen40_38.TDK_Gen40_38
    :members:
    :show-inheritance:
    :inherited-members: CommonBase
